@@ -8,35 +8,141 @@ SEMRUSH_ASNS_API_URL = 'http://api.asns.backend.semrush.com/'
 SEMRUSH_API_V1_URL = 'http://api.semrush.com/analytics/v1/'
 
 REGIONAL_DATABASES = {
-    'google.com': 'us',
-    'google.co.uk': 'uk',
-    'google.ca': 'ca',
-    'google.ru': 'ru',
-    'google.de': 'de',
-    'google.fr': 'fr',
-    'google.es': 'es',
-    'google.it': 'it',
-    'google.com.br': 'br',
-    'google.com.au': 'au',
-    'bing.com': 'bing-us',
-    'google.com.ar': 'ar',
-    'google.be': 'be',
-    'google.ch': 'ch',
-    'google.dk': 'dk',
-    'google.fi': 'fi',
-    'google.com.hk': 'hk',
-    'google.ie': 'ie',
-    'google.co.il': 'il',
-    'google.com.mx': 'mx',
-    'google.nl': 'nl',
-    'google.no': 'no',
-    'google.pl': 'pl',
-    'google.se': 'se',
-    'google.com.sg': 'sg',
-    'google.com.tr': 'tr',
-    'm.google.com': 'mobile-us',
-    'google.co.jp': 'jp',
-    'google.co.in': 'in'
+    'us': 'google.com',
+    'uk': 'google.co.uk',
+    'ca': 'google.ca',
+    'ru': 'google.ru',
+    'de': 'google.de',
+    'fr': 'google.fr',
+    'es': 'google.es',
+    'it': 'google.it',
+    'br': 'google.com.br',
+    'au': 'google.com.au',
+    'ar': 'google.com.ar',
+    'be': 'google.be',
+    'ch': 'google.ch',
+    'dk': 'google.dk',
+    'fi': 'google.fi',
+    'hk': 'google.com.hk',
+    'ie': 'google.ie',
+    'il': 'google.co.il',
+    'mx': 'google.com.mx',
+    'nl': 'google.nl',
+    'no': 'google.no',
+    'pl': 'google.pl',
+    'se': 'google.se',
+    'sg': 'google.com.sg',
+    'tr': 'google.com.tr',
+    'jp': 'google.co.jp',
+    'in': 'google.co.in',
+    'hu': 'google.hu',
+    'af': 'google.com.af',
+    'al': 'google.al',
+    'dz': 'google.dz',
+    'ao': 'google.co.ao', 
+    'am': 'google.am', 
+    'at': 'google.at', 
+    'az': 'google.az', 
+    'bh': 'google.com.bh',
+    'bd': 'google.com.bd',
+    'by': 'google.by',
+    'bz': 'google.com.bz',
+    'bo': 'google.com.bo',
+    'ba': 'google.ba',
+    'bw': 'google.co.bw', 
+    'bn': 'google.com.bn', 
+    'bg': 'google.bg', 
+    'cv': 'google.cv', 
+    'kh': 'google.com.kh',
+    'cm': 'google.cm',
+    'cl': 'google.cl',
+    'co': 'google.com.co',
+    'cr': 'google.co.cr',
+    'hr': 'google.hr',
+    'cy': 'google.com.cy',
+    'cz': 'google.cz',
+    'cd': 'google.cd',
+    'do': 'google.com.do',
+    'ec': 'google.com.ec',
+    'eg': 'google.com.eg',
+    'sv': 'google.com.sv',
+    'ee': 'google.ee',
+    'et': 'google.com.et',
+    'ge': 'google.ge',
+    'gh': 'google.com.gh',
+    'gr': 'google.gr',
+    'gt': 'google.com.gt',
+    'gy': 'google.gy',
+    'ht': 'google.ht',
+    'hn': 'google.hn',
+    'is': 'google.is',
+    'id': 'google.co.id',
+    'jm': 'google.com.jm',
+    'jo': 'google.jo',
+    'kz': 'google.kz',
+    'kw': 'google.com.kw',
+    'lv': 'google.lv',
+    'lb': 'google.com.lb',
+    'lt': 'google.lt',
+    'lu': 'google.lu',
+    'mg': 'google.mg',
+    'my': 'google.com.my',
+    'mt': 'google.com.mt',
+    'mu': 'google.mu',
+    'md': 'google.md',
+    'mn': 'google.mn',
+    'me': 'google.me',
+    'ma': 'google.co.ma',
+    'mz': 'google.co.mz',
+    'na': 'google.com.na',
+    'np': 'google.com.np',
+    'nz': 'google.co.nz',
+    'ni': 'google.com.ni',
+    'ng': 'google.com.ng',
+    'om': 'google.com.om',
+    'py': 'google.com.py',
+    'pe': 'google.com.pe',
+    'ph': 'google.com.ph',
+    'pt': 'google.pt',
+    'pk': 'google.com.pk',
+    'ro': 'google.ro',
+    'sa': 'google.com.sa',
+    'sn': 'google.sn',
+    'rs': 'google.rs',
+    'sk': 'google.sk',
+    'si': 'google.si',
+    'za': 'google.co.za',
+    'kr': 'google.co.kr',
+    'lk': 'google.lk',
+    'th': 'google.co.th',
+    'bs': 'google.bs',
+    'tt': 'google.tt',
+    'tn': 'google.tn',
+    'ua': 'google.com.ua',
+    'ae': 'google.ae',
+    'uy': 'google.com.uy',
+    've': 'google.co.ve',
+    'vn': 'google.com.vn',
+    'zm': 'google.co.zm',
+    'zw': 'google.co.zw',
+    'ly': 'google.com.ly',
+    'mobile-us': 'google.com',
+    'mobile-uk': 'google.com',
+    'mobile-ca': 'google.ca',
+    'mobile-de': 'google.de',
+    'mobile-fr': 'google.fr',
+    'mobile-es': 'google.es',
+    'mobile-it': 'google.it',
+    'mobile-br': 'google.com.br',
+    'mobile-au': 'google.com.au',
+    'mobile-dk': 'google.dk',
+    'mobile-mx': 'google.com.mx',
+    'mobile-nl': 'google.nl',
+    'mobile-se': 'google.se',
+    'mobile-tr': 'google.com.tr',
+    'mobile-in': 'google.co.in',
+    'mobile-id': 'google.co.id',
+    'mobile-il': 'google.co.il'
 }
 
 
@@ -75,7 +181,7 @@ class SemrushClient(object):
     @staticmethod
     def parse_response(data):
         results = []
-        data = data.decode('unicode_escape')
+        data = data.decode('utf8')
         lines = data.split('\r\n')
         lines = list(filter(bool, lines))
         columns = lines[0].split(';')
